@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m3Func.php 3551 2010-08-30 07:18:13Z fishbone $
+ * @version    SVN: $Id: m3Func.php 3827 2010-11-16 06:19:36Z fishbone $
  * @link       http://www.magic3.org
  */
 /**
@@ -545,7 +545,7 @@ function convFromBytes($val)
 	return ceil($destVal) . 'G';
 }
 /**
- * URL以外をエンティティ文字に変換
+ * URL以外の文字列をエンティティ文字に変換
  *
  * @param string $src		変換元文字列
  * @param bool $keepTags	HTMLタグを変換するかどうか
@@ -563,6 +563,18 @@ function convertToHtmlEntity($src, $keepTags = false)
 		return htmlentities($src, ENT_COMPAT, M3_HTML_CHARSET);
 	}
 }
+/**
+ * エンティティ文字を元の文字列に変換
+ *
+ * @param string $src		変換元文字列
+ * @return string			変換後文字列
+ */
+function convertFromHtmlEntity($src)
+{
+	$transTable = get_html_translation_table(HTML_ENTITIES);
+	$transTable = array_flip($transTable);
+	return strtr($src, $transTable);
+}
 /**
  * タグ以外変換コールバック関数
  *
