@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 3710 2010-10-18 02:57:50Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 3854 2010-11-21 12:06:30Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -24,6 +24,8 @@ class ScriptLibInfo
 	const LIB_JQUERY_UI_PLUS		= 'jquery-ui-plus';
 	const LIB_FCKEDITOR				= 'fckeditor';
 	const LIB_MD5					= 'md5';
+	const LIB_SWFOBJECT				= 'swfobject';
+	
 	// jQueryプラグイン
 	const LIB_JQUERY_EASING			= 'jquery.easing';
 	const LIB_JQUERY_JCAROUSEL		= 'jquery.jcarousel';
@@ -46,6 +48,7 @@ class ScriptLibInfo
 	const LIB_JQUERY_QTIP			= 'jquery.qtip';
 	const LIB_JQUERY_CALCULATION	= 'jquery.calculation';
 	const LIB_JQUERY_JQPLOT			= 'jquery.jqplot';
+	const LIB_JQUERY_YOUTUBEPLAYER	= 'jquery.youtubeplayer';
 	
 	// jQueryプラグインバージョン
 	const JQUERY_PRETTYPHOTO_VER	= '2.5.6';
@@ -95,6 +98,7 @@ class ScriptLibInfo
 	const JQUERY_JQPLOT_FILENAME		= 'jquery/jqplot/jquery.jqplot.min.js';
 //	const JQUERY_JQPLOT_EX_FILENAME		= 'jquery/jqplot/excanvas.min.js';
 	const JQUERY_JQPLOT_CSS				= 'jquery/jqplot/jquery.jqplot.css';
+	const JQUERY_YOUTUBEPLAYER_FILENAME	= 'jquery/jquery.youtube.player.js';
 	
 	// ライブラリの公式サイトのURL
 	const JQUERY_CLUETIP_URL			= 'http://plugins.learningjquery.com/cluetip/';
@@ -118,6 +122,8 @@ class ScriptLibInfo
 //	const FCKEDITOR_FILENAME		= 'fckeditor2.6/fckeditor.js';				// FCKEditor
 	const FCKEDITOR_FILENAME		= 'fckeditor2.6.6/fckeditor.js';			// FCKEditor
 	const MD5_FILENAME				= 'md5.js';									// MD5
+	const SWFOBJECT_FILENAME		= 'swfobject/swfobject.js';					// swfobject
+	
 	// jQuery UI用ファイル
 	const JQUERY_UI_WIDGETS_ACCORDION_FILENAME		= 'jquery/ui/1.8.2/jquery.ui.accordion.min.js';		// Widgets Accordion
 	const JQUERY_UI_WIDGETS_AUTOCOMPLETE_FILENAME	= 'jquery/ui/1.8.2/jquery.ui.autocomplete.min.js';		// Widgets Autocomplete
@@ -192,6 +198,7 @@ class ScriptLibInfo
 	{
 		$libs = array(self::LIB_MD5					=>	array(	'script' 	=> array(self::MD5_FILENAME)),			// MD5
 					self::LIB_FCKEDITOR				=>	array(	'script' 	=> array(self::FCKEDITOR_FILENAME)),	// FCKEditor
+					self::LIB_SWFOBJECT				=>	array(	'script' 	=> array(self::SWFOBJECT_FILENAME)),	// swfobject
 					
 					// jQueryライブラリ
 					self::LIB_JQUERY_EASING			=>	array(	'script' 	=> array(self::JQUERY_EASING_FILENAME)),		// jquery.easing用のファイル
@@ -232,7 +239,8 @@ class ScriptLibInfo
 					self::LIB_JQUERY_JQPLOT			=>	array(	'script' 	=> array(self::JQUERY_JQPLOT_FILENAME),	// jquery.jqplot用のファイル
 																'css'		=>	array(self::JQUERY_JQPLOT_CSS),
 																'url'		=>	self::JQUERY_JQPLOT_URL,
-																'version'	=>	self::JQUERY_JQPLOT_VER)
+																'version'	=>	self::JQUERY_JQPLOT_VER),
+					self::LIB_JQUERY_YOUTUBEPLAYER	=>	array(	'script'	=> array(self::JQUERY_YOUTUBEPLAYER_FILENAME)),// jquery.youtubeplayer用のファイル
 																);
 					
 		// 使用するjQueryバージョンに合わせてファイルを追加
