@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 3695 2010-10-13 05:33:05Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 3752 2010-10-29 01:43:18Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -302,8 +302,26 @@ class BaseFrameContainer extends Core
 		
 				// 画面を作成
 				$pageData = $this->_createPage($request, $curTemplateId);
-				$this->gCache->setPageCache($request, $pageData);		// キャッシュデータを設定
-				echo $pageData;
+				
+				// 使用した非共通ウィジェットの数をチェック
+				$nonSharedWidgetCount = $this->gPage->getNonSharedWidgetCount();
+				if ($nonSharedWidgetCount == -1){		// カウントなしの場合
+					$this->gCache->setPageCache($request, $pageData);		// キャッシュデータを設定
+					echo $pageData;
+				} else {
+					if ($isSystemAdmin || $nonSharedWidgetCount > 0){
+						$this->gCache->setPageCache($request, $pageData);		// キャッシュデータを設定
+						echo $pageData;
+					} else {		// 管理者以外で、非共通のウィジェットが使用されていないページはアクセス不可とする
+						// アクセス不可ページへ遷移
+						$this->gPage->redirect('?' . M3_REQUEST_PARAM_PAGE_SUB_ID . '=_accessdeny');
+						// システム制御モードに変更
+						//$this->gPage->setSystemHandleMode(11/*アクセス不可*/);
+
+						// システム制御画面を表示
+						//$this->_showSystemPage($request, 0/*アクセス不可画面*/);
+					}
+				}
 			} else {
 				echo $cacheData;
 			}
