@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2010 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_std.sql 3639 2010-09-27 09:54:19Z fishbone $
+-- * @version    SVN: $Id: insert_std.sql 3811 2010-11-12 10:07:10Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -19,13 +19,19 @@
 
 -- 管理画面メニューデータ
 DELETE FROM _nav_item WHERE ni_id >= 500 AND ni_id < 1000;
+DELETE FROM _nav_item WHERE ni_id >= 10500 AND ni_id < 11000;
 INSERT INTO _nav_item
 (ni_id, ni_parent_id, ni_index, ni_nav_id,    ni_task_id,                      ni_view_control, ni_param, ni_name,    ni_help_title, ni_help_body) VALUES
 (500,   0,            4,        'admin_menu', '_widget',                       0,               '',       'ウィジェット設定', 'ウィジェット設定', '個別のウィジェットの設定を行います。'),
 (501,   500,          0,        'admin_menu', 'configwidget_default_content',  0,               '',       '汎用コンテンツメイン', 'デフォルトコンテンツ', 'Webサイトのコンテンツを管理する設定画面です。'),
 (502,   500,          1,        'admin_menu', 'configwidget_ec_main',          0,               '',       'Eコマースメイン', 'Eコマースメイン', 'Eコマース機能のメインの管理画面です。'),
 (503,   500,          2,        'admin_menu', 'configwidget_blog_main',        0,               '',       'ブログメイン', 'ブログメイン', 'ブログ機能のメインの管理画面です。'),
-(504,   500,          3,        'admin_menu', 'configwidget_wiki_main',        0,               '',       'Wikiメイン', 'Wikiメイン', 'Wiki機能のメインの管理画面です。');
+(504,   500,          3,        'admin_menu', 'configwidget_wiki_main',        0,               '',       'Wikiメイン', 'Wikiメイン', 'Wiki機能のメインの管理画面です。'),
+(10500,   0,            4,        'admin_menu.en', '_widget',                       0,               '',       'Widget Administration', 'Widget Administration', 'Administrate widgets with widget config window.'),
+(10501,   10500,          0,        'admin_menu.en', 'configwidget_default_content',  0,               '',       'Main For Standard Contents', 'Main For Standard Contents', 'Main function to administrate standard contents.'),
+(10502,   10500,          1,        'admin_menu.en', 'configwidget_ec_main',          0,               '',       'Main For E-Commerce', 'Main For E-Commerce', 'Main function to administrate E-Commerce.'),
+(10503,   10500,          2,        'admin_menu.en', 'configwidget_blog_main',        0,               '',       'Main For Blog', 'Main For Blog', 'Main function to administrate Blog.'),
+(10504,   10500,          3,        'admin_menu.en', 'configwidget_wiki_main',        0,               '',       'Main For Wiki', 'Main For Wiki', 'Main function to administrate Wiki.');
 
 -- Wiki設定マスター
 INSERT INTO wiki_config (wg_id,        wg_value,     wg_name,                 wg_index)
