@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainAnalyzegraphWidgetContainer.php 3714 2010-10-19 04:21:03Z fishbone $
+ * @version    SVN: $Id: admin_mainAnalyzegraphWidgetContainer.php 3751 2010-10-29 01:42:44Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainAnalyzeBaseWidgetContainer.php');
@@ -22,6 +22,7 @@ class admin_mainAnalyzegraphWidgetContainer extends admin_mainAnalyzeBaseWidgetC
 	private $analyzeDb;
 	private $sysDb;	// システム情報取得用
 	private $termTypeArray;		// 期間タイプ
+	private $graphType;			// グラフ種別
 	private $path;				// アクセスパス
 	private $termType;				// 期間タイプ
 	private $completedDate;			// 処理終了日付
@@ -32,9 +33,9 @@ class admin_mainAnalyzegraphWidgetContainer extends admin_mainAnalyzeBaseWidgetC
 	const DEFAULT_STR_NOT_CALC = '未集計';		// 未集計時の表示文字列
 	const DEFAULT_ACCESS_PATH = 'index';		// デフォルトのアクセスパス(PC用アクセスポイント)
 	const ACCESS_PATH_ALL = '_all';				// アクセスパスすべて選択
-	const ACCESS_PATH_OTHER = '_other';				// アクセスパスその他
 	const DEFAULT_TERM_TYPE = '30day';		// デフォルトの期間タイプ
 	const TERM_TYPE_ALL = '_all';				// 全データ表示選択
+	const DEFAULT_GRAPH_TYPE = 'pageview';		// デフォルトのグラフ種別
 	
 	/**
 	 * コンストラクタ
@@ -48,6 +49,11 @@ class admin_mainAnalyzegraphWidgetContainer extends admin_mainAnalyzeBaseWidgetC
 		$this->db = new admin_analyzeDb();
 		$this->sysDb = $this->gInstance->getSytemDbObject();
 		
+		// グラフタイプ
+		$this->graphTypeArray = array(	array(	'name' => 'ページビュー',	'value' => 'pageview'),
+										array(	'name' => '訪問数',			'value' => 'visit'),
+										array(	'name' => '訪問者数',		'value' => 'visitor'));
+										
 		// 期間タイプ
 		$this->termTypeArray = array(	array(	'name' => '30日',	'value' => '30day'),
 										array(	'name' => '3ヶ月',	'value' => '3month'),
@@ -82,6 +88,8 @@ class admin_mainAnalyzegraphWidgetContainer extends admin_mainAnalyzeBaseWidgetC
 	function _assign($request, &$param)
 	{
 		$act = $request->trimValueOf('act');
+		$this->graphType = $request->trimValueOf('graphtype');			// グラフ種別
+		if (empty($this->graphType)) $this->graphType = self::DEFAULT_GRAPH_TYPE;
 		$this->path = $request->trimValueOf('path');		// アクセスパス
 		if (empty($this->path)) $this->path = self::DEFAULT_ACCESS_PATH;
 		$this->termType = $request->trimValueOf('term');				// 期間タイプ
@@ -124,20 +132,30 @@ class admin_mainAnalyzegraphWidgetContainer extends admin_mainAnalyzeBaseWidgetC
 				$this->completedDate = date("Y/m/d", strtotime("$startDate -1 day"));// 処理終了日付を前日に設定
 			}
 			
-			// データ取得
+			// パスパラメータ作成
 			$pathParam = $this->path;
 			if ($pathParam == self::ACCESS_PATH_ALL){
 				$pathParam = NULL;
-			} else if ($pathParam == self::ACCESS_PATH_OTHER){		// その他のパス
-				$pathParam = '';
 			}
-			$this->db->getPageViewByDate($pathParam, $startDate, $endDate, array($this, 'pageViewDataLoop'));
 			
+			// ##### グラフ種別に応じてデータ取得 #####
+			switch ($this->graphType){
+				case 'pageview':		//ページビュー
+					// データ取得
+					$this->db->getPageViewByDate($pathParam, $startDate, $endDate, array($this, 'pageViewDataLoop'));
+					break;
+				case 'visit':			// 訪問数
+					$this->db->getDailyCountByDate(0/*訪問数*/, $pathParam, $startDate, $endDate, array($this, 'pageViewDataLoop'));
+					break;
+				case 'visitor':			// 訪問者数
+					$this->db->getDailyCountByDate(1/*訪問者数*/, $pathParam, $startDate, $endDate, array($this, 'pageViewDataLoop'));
+					break;
+			}
 			// 集計終了日までのデータを作成
 			$startDate = date("Y/m/d", strtotime("$this->completedDate 1 day"));		// 処理終了日翌日
 			$this->createGraphData($startDate, $endDate);
-			
-			// グラフデータ埋め込み
+					
+			// ##### グラフデータ埋め込み #####
 			$this->graphDataStr = trim($this->graphDataStr, ',');		// グラフデータ
 			if (empty($this->graphDataStr)){
 				$this->setMsg(self::MSG_GUIDANCE, '集計済みのデータがありません');
@@ -157,6 +175,8 @@ class admin_mainAnalyzegraphWidgetContainer extends admin_mainAnalyzeBaseWidgetC
 				$this->tmpl->addVar("draw_graph", "line1_data", $this->graphDataStr);
 			}
 		}
+		// グラフ種別メニュー作成
+		$this->createGraphTypeMenu();
 		
 		// アクセスポイントメニュー作成
 		$this->createPathMenu();
@@ -164,6 +184,29 @@ class admin_mainAnalyzegraphWidgetContainer extends admin_mainAnalyzeBaseWidgetC
 		// 期間メニュー作成
 		$this->createTermMenu();
 	}
+	/**
+	 * グラフ種別メニュー作成
+	 *
+	 * @return なし
+	 */
+	function createGraphTypeMenu()
+	{
+		for ($i = 0; $i < count($this->graphTypeArray); $i++){
+			$value = $this->graphTypeArray[$i]['value'];
+			$name = $this->graphTypeArray[$i]['name'];
+			
+			$selected = '';
+			if ($value == $this->graphType) $selected = 'selected';
+			
+			$row = array(
+				'value'    => $value,			// グラフ種別ID
+				'name'     => $name,			// グラフ種別
+				'selected' => $selected			// 選択中かどうか
+			);
+			$this->tmpl->addVars('graphtype_list', $row);
+			$this->tmpl->parseTemplate('graphtype_list', 'a');
+		}
+	}
 	/**
 	 * アクセスパスメニュー作成
 	 *
@@ -184,18 +227,6 @@ class admin_mainAnalyzegraphWidgetContainer extends admin_mainAnalyzeBaseWidgetC
 		$this->tmpl->parseTemplate('path_list', 'a');
 		
 		$this->_db->getPageIdList(array($this, 'pageIdLoop'), 0/*ページID*/);
-		
-		$selected = '';
-		if ($this->path == self::ACCESS_PATH_OTHER){// アクセスパスその他
-			$selected = 'selected';
-		}
-		$row = array(
-			'value'    => self::ACCESS_PATH_OTHER,			// アクセスパス
-			'name'     => 'その他',			// 表示文字列
-			'selected' => $selected														// 選択中かどうか
-		);
-		$this->tmpl->addVars('path_list', $row);
-		$this->tmpl->parseTemplate('path_list', 'a');
 	}
 	/**
 	 * ページID、取得したデータをテンプレートに設定する
@@ -254,7 +285,16 @@ class admin_mainAnalyzegraphWidgetContainer extends admin_mainAnalyzeBaseWidgetC
 	 */
 	function pageViewDataLoop($index, $fetchedRow, $param)
 	{
-		$pvDate = $fetchedRow['ap_date'];
+		// 日付を取得
+		switch ($this->graphType){
+			case 'pageview':		//ページビュー
+				$pvDate = $fetchedRow['ap_date'];
+				break;
+			case 'visit':			// 訪問数
+			case 'visitor':			// 訪問者数
+				$pvDate = $fetchedRow['aa_date'];
+				break;
+		}
 		$endDate = date("Y/m/d", strtotime("$pvDate -1 day"));		// 1日前
 		$total = $fetchedRow['total'];
 		if ($total > $this->maxPv) $this->maxPv = $total;				// 日次のページビュー最大値
