@@ -8,16 +8,16 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainResbrowseWidgetContainer.php 2234 2009-08-18 01:51:31Z fishbone $
+ * @version    SVN: $Id: admin_mainResbrowseWidgetContainer.php 3492 2010-08-17 06:18:43Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_mainBrowseBaseWidgetContainer.php');
 
 class admin_mainResbrowseWidgetContainer extends admin_mainBrowseBaseWidgetContainer
 {
-	const FILE_BROWSER_PATH = '/fckeditor2.6/editor/plugins/FileBrowser_Thumbnail/browser.html?Lang=ja&Connector=connectors/php/connector.php';		// ファイルブラウザのパス
+	const FILE_BROWSER_PATH = '/editor/plugins/FileBrowser_Thumbnail/browser.html?Lang=ja&Connector=connectors/php/connector.php';		// ファイルブラウザのパス
 	
 	/**
 	 * コンストラクタ
@@ -52,7 +52,8 @@ class admin_mainResbrowseWidgetContainer extends admin_mainBrowseBaseWidgetConta
 	 */
 	function _assign($request, &$param)
 	{
-		$this->tmpl->addVar('_widget', 'url', $this->getUrl($this->gEnv->getScriptsUrl() . self::FILE_BROWSER_PATH));
+		$browserPath = $this->gEnv->getScriptsUrl() . '/' . ScriptLibInfo::FCKEDITOR_DIRNAME . self::FILE_BROWSER_PATH;
+		$this->tmpl->addVar('_widget', 'url', $this->getUrl($browserPath));
 		$this->tmpl->addVar('_widget', 'res_dir', $this->gEnv->getResourcePath());// リソースディレクトリ
 	}
 }
