@@ -8,35 +8,36 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainUsercustomWidgetContainer.php 284 2008-02-06 09:12:15Z fishbone $
+ * @version    SVN: $Id: admin_mainUsercustomWidgetContainer.php 2235 2009-08-19 02:00:26Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
+//require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
 
-class admin_mainUsercustomWidgetContainer extends BaseWidgetContainer
+class admin_mainUsercustomWidgetContainer extends admin_mainBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
 	private $sysDb;		// システムDBオブジェクト
 	private $maxNo;	// 最大項目番号
 	const KEY_HEAD = 'CUSTOM_KEY_';			// 置換キー
 	const KEY_GROUP = 'user';				// 置換キーの所属グループ
+	const VIEW_STR_LENGTH = 20;			// 表示文字数
+	const ADD_STR = '...';				// 文字列を省略する場合の記号
 	
 	/**
 	 * コンストラクタ
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
 		// DBオブジェクト作成
 		$this->db = new admin_mainDb();
-		$this->sysDb = $gInstanceManager->getSytemDbObject();
+		$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -63,9 +64,7 @@ class admin_mainUsercustomWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		
-		$defaultLang	= $gEnvManager->getDefaultLanguage();
+		$defaultLang	= $this->gEnv->getDefaultLanguage();
 		
 		$this->id	= $request->trimValueOf('id');	// ID
 		$addid		= $request->trimValueOf('addid');	// 追加ID
@@ -90,12 +89,12 @@ class admin_mainUsercustomWidgetContainer extends BaseWidgetContainer
 			if ($this->getMsgCount() == 0){
 				$ret = $this->sysDb->updateKeyValue($this->id, $value, $name, self::KEY_GROUP);
 				if ($ret){		// データ追加成功のとき
-					$this->setMsg(self::MSG_GUIDANCE, 'データを追加しました');
+					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 					
 					//$this->id = $addid;		// 新規IDに更新
 					$replaceNew = true;			// データを再取得
 				} else {
-					$this->setMsg(self::MSG_APP_ERR, 'データ追加に失敗しました');
+					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
 				}
 			}
 		} else if ($act == 'add'){		// 新規追加のとき
@@ -155,13 +154,6 @@ class admin_mainUsercustomWidgetContainer extends BaseWidgetContainer
 	 */
 	function keyLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
-		// 行カラーの設定
-		$lineColor = '';
-		if ($index % 2 != 0){
-			$lineColor = 'class="even"';		// 偶数行
-		}
 		// 項目選択のラジオボタンの状態
 		$selected = '';
 		if ($fetchedRow['kv_id'] == $this->id){
@@ -174,11 +166,22 @@ class admin_mainUsercustomWidgetContainer extends BaseWidgetContainer
 		
 		$id = $fetchedRow['kv_id'];
 		$key = M3_TAG_START . $id . M3_TAG_END;
+		
+		// 値
+		$addValue = '';
+		$srcValue = $fetchedRow['kv_value'];
+		if (function_exists('mb_substr')){
+			if (mb_strlen($srcValue) > self::VIEW_STR_LENGTH) $addValue = self::ADD_STR;
+			$value = mb_substr($srcValue, 0, self::VIEW_STR_LENGTH) . $addValue;
+		} else {
+			if (strlen($srcValue) > self::VIEW_STR_LENGTH) $addValue = self::ADD_STR;
+			$value = substr($srcValue, 0, self::VIEW_STR_LENGTH) . $addValue;
+		}
 		$row = array(
-			'line_color' => $lineColor,			// 行のカラー
 			'id' =>	$id,									
 			'key'    => $key,
 			'name'     => $this->convertToDispString($fetchedRow['kv_name']),			// 表示名
+			'value'	=> $this->convertToDispString($value),					// 値
 			'checked' => $selected												// 項目選択用ラジオボタン
 		);
 		$this->tmpl->addVars('key_list', $row);
