@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainWidgetlistWidgetContainer.php 3324 2010-07-02 03:10:33Z fishbone $
+ * @version    SVN: $Id: admin_mainWidgetlistWidgetContainer.php 3871 2010-12-01 10:08:24Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -31,7 +31,6 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 	const CSS_FILE_EXT = 'css';		// cssファイル拡張子
 	const PHP_FILE_EXT = 'php';		// phpファイル拡張子
 	const NOT_FOUND_WIDGET_ICON_FILE = '/images/system/notfound32.png';		// ウィジェットが見つからないアイコン
-	const NOT_FOUND_WIDGET_MESSAGE = 'ウィジェットが見つかりません';
 	
 	/**
 	 * コンストラクタ
@@ -45,9 +44,9 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 		$this->db = new admin_mainDb();
 		
 		// ウィジェットタイプメニュー項目
-		$this->widgetTypeArray = array(	array(	'name' => 'PC用',				'value' => '0'),
-										array(	'name' => '携帯用',				'value' => '1'),
-										array(	'name' => 'スマートフォン用',	'value' => '2'));
+		$this->widgetTypeArray = array(	array(	'name' => $this->_('For PC'),			'value' => '0'),	// PC用
+										array(	'name' => $this->_('For Mobile'),		'value' => '1'),	// 携帯用
+										array(	'name' => $this->_('For Smartphone'),	'value' => '2'));	// スマートフォン用
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -63,6 +62,20 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 	{	
 		return 'widgetlist.tmpl.html';
 	}
+	/**
+	 * ヘルプデータを設定
+	 *
+	 * ヘルプの設定を行う場合はヘルプIDを返す。
+	 * ヘルプデータの読み込むディレクトリは「自ウィジェットディレクトリ/include/help」に固定。
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
+	 * @return string 						ヘルプID。ヘルプデータはファイル名「help_[ヘルプID].php」で作成。ヘルプを使用しない場合は空文字列「''」を返す。
+	 */
+	function _setHelp($request, &$param)
+	{	
+		return 'widgetlist';
+	}
 	/**
 	 * テンプレートにデータ埋め込む
 	 *
@@ -99,11 +112,6 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 						$searchPath = $this->gEnv->getWidgetsPath() . '/' . M3_DIR_NAME_SMARTPHONE;
 						break;
 				}
-				/*if ($this->widgetType == '0'){		// PC用ウィジェット
-					$searchPath = $this->gEnv->getWidgetsPath();
-				} else {		// 携帯用ウィジェット
-					$searchPath = $this->gEnv->getWidgetsPath() . '/' . M3_DIR_NAME_MOBILE;
-				}*/
 				
 				if (is_dir($searchPath)){
 					$dir = dir($searchPath);
@@ -112,7 +120,7 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 						// ディレクトリかどうかチェック
 						if (strncmp($file, '.', 1) != 0 && $file != '..' && is_dir($filePath)
 								&& strncmp($file, '_', 1) != 0		// 「_」で始まる名前のディレクトリは読み込まない
-								&& strcmp($file, 'm') != 0){		// 携帯用のディレクトリ「m」は読み込まない
+								&& strlen($file) > 1){		// 1文字のディレクトリは読み込まない
 							// ウィジェットIDを作成
 							switch ($this->widgetType){
 								case '0':		// PC用テンプレート
@@ -126,11 +134,6 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 									$widgetId = M3_DIR_NAME_SMARTPHONE . '/' . $file;
 									break;
 							}
-							/*if ($this->widgetType == '0'){		// PC用
-								$widgetId = $file;
-							} else {		// 携帯用
-								$widgetId = M3_DIR_NAME_MOBILE . '/' . $file;
-							}*/
 							
 							// DBに登録されていない場合は登録
 							for ($i = 0; $i < count($rows); $i++){
@@ -157,9 +160,11 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 			}
 			// 終了メッセージを表示
 			if ($addWidgetCount > 0){
-				$msg = '新規ウィジェットを追加しました(追加数=' . $addWidgetCount . ')';
+				//$msg = '新規ウィジェットを追加しました(追加数=' . $addWidgetCount . ')';
+				$msg = sprintf($this->_('New widgets added. (widgets count=%d)'), $addWidgetCount);			// 新規ウィジェットを追加しました(追加数=%d)
 			} else {
-				$msg = '新規ウィジェットはありません';
+				//$msg = '新規ウィジェットはありません';
+				$msg = $this->_('No new widgets added.');		// 新規ウィジェットはありません
 			}
 			$this->setMsg(self::MSG_GUIDANCE, $msg);
 		} else if ($act == 'updateline'){		// 行更新のとき
@@ -170,9 +175,11 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 			
 			$ret = $this->db->updateWidget($serial, $updateName, $updateAvailable, $updateActive);
 			if ($ret){		// データ更新成功のとき
-				$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
+				//$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
+				$this->setMsg(self::MSG_GUIDANCE, $this->_('Line updated.'));		// データを更新しました
 			} else {
-				$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
+				//$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
+				$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in updating line.'));	// データ更新に失敗しました
 			}
 		} else if ($act == 'deleteline'){		// ウィジェット削除のとき
 			// ウィジェットが参照状況をチェック、参照されている場合は削除できない
@@ -199,19 +206,19 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 					// ディレクトリ削除
 					if ((is_dir($widgetPath) && rmDirectory($widgetPath)) || !is_dir($widgetPath)){// 削除成功か、ディレクトリが存在しないとき
 						$ret = $this->db->deleteWidget($serial);
-						//if ($ret){		// データ更新成功のとき
-							$this->setMsg(self::MSG_GUIDANCE, 'ウィジェットを削除しました(ウィジェットID：' . $widgetId . ')');
-						//} else {
-						//	$this->setMsg(self::MSG_APP_ERR, 'ウィジェット削除に失敗しました');
-						//}
+						//$this->setMsg(self::MSG_GUIDANCE, 'ウィジェットを削除しました(ウィジェットID：' . $widgetId . ')');
+						$this->setMsg(self::MSG_GUIDANCE, sprintf($this->_('Widget deleted. (widget ID: %s)'), $widgetId));	// ウィジェットを削除しました(ウィジェットID：%s)
 					} else {
-						$this->setMsg(self::MSG_APP_ERR, 'ウィジェットのディレクトリが削除できませんでした(ディレクトリ：' . $widgetPath . ')');
+						//$this->setMsg(self::MSG_APP_ERR, 'ウィジェットのディレクトリが削除できませんでした(ディレクトリ：' . $widgetPath . ')');
+						$this->setMsg(self::MSG_APP_ERR, sprintf($this->_('Failed in deleting widget directory. (directory: %s)'), $widgetPath));	// ウィジェットのディレクトリが削除できませんでした(ディレクトリ：%s)
 					}
 				} else {
-					$this->setMsg(self::MSG_APP_ERR, 'ウィジェットのディレクトリの削除権限がありません(ディレクトリ：' . $widgetPath . ')');
+					//$this->setMsg(self::MSG_APP_ERR, 'ウィジェットのディレクトリの削除権限がありません(ディレクトリ：' . $widgetPath . ')');
+					$this->setMsg(self::MSG_APP_ERR, sprintf($this->_('You are not allowed to delete widget directory. (directory: %s)'), $widgetPath));		// ウィジェットのディレクトリの削除権限がありません(ディレクトリ：%s)
 				}
 			} else {
-				$this->setMsg(self::MSG_APP_ERR, '削除対象のウィジェットが見つかりません');
+				//$this->setMsg(self::MSG_APP_ERR, '削除対象のウィジェットが見つかりません');
+				$this->setMsg(self::MSG_APP_ERR, $this->_('Widget not found.'));		// 削除対象のウィジェットが見つかりません
 			}
 		} else if ($act == 'upload'){		// ファイルアップロードの場合
 			$replaceWidget = ($request->trimValueOf('item_replace') == 'on') ? 1 : 0;		// ウィジェットを置き換えるかどうか
@@ -238,34 +245,27 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 						$widgetId = M3_DIR_NAME_SMARTPHONE . '/' . $widgetId;
 						break;
 				}
-				//if ($this->widgetType != '0') $widgetId = M3_DIR_NAME_MOBILE . '/' . $widgetId;// 携帯の場合はIDを修正
 				
 				// ファイル拡張子のチェック
 				if ($ext != 'zip'){
-					$msg = 'zip圧縮のファイルのみアップロード可能です';
+					//$msg = 'zip圧縮のファイルのみアップロード可能です';
+					$msg = $this->_('Only zip format file is allowed to upload.');	// zip圧縮のファイルのみアップロード可能です
 					$this->setAppErrorMsg($msg);
 				}
 				
 				// テンポラリディレクトリの書き込み権限をチェック
 				if (!is_writable($this->gEnv->getWorkDirPath())){
-					$msg = '一時ディレクトリに書き込み権限がありません。ディレクトリ：' . $this->gEnv->getWorkDirPath();
+					//$msg = '一時ディレクトリに書き込み権限がありません。ディレクトリ：' . $this->gEnv->getWorkDirPath();
+					$msg = sprintf($this->_('You are not allowed to write temporary directory. (directory: %s)'), $this->gEnv->getWorkDirPath());	// 一時ディレクトリに書き込み権限がありません。(ディレクトリ：%s)
 					$this->setAppErrorMsg($msg);
 				}
 				
 				if ($this->getMsgCount() == 0){		// エラーが発生していないとき
 					if (!$replaceWidget){		// ウィジェット置き換えないとき
 						// 同じIDのウィジェットがないかチェック
-						/*if ($this->db->getAllWidgetIdList($rows)){
-							for ($i = 0; $i < count($rows); $i++){
-								if ($widgetId == $rows[$i]['wd_id']) break;
-							}
-							if ($i < count($rows)){
-								$msg = 'ウィジェットがすでに存在します(ウィジェットID：' . $widgetId . ')';
-								$this->setAppErrorMsg($msg);
-							}
-						}*/
 						if ($this->db->isExistsWidgetId($widgetId)){
-							$msg = 'ウィジェットがすでに存在します(ウィジェットID：' . $widgetId . ')';
+							//$msg = 'ウィジェットがすでに存在します(ウィジェットID：' . $widgetId . ')';
+							$msg = sprintf($this->_('The widget already exists. (widget ID: %s)'), $widgetId);		// ウィジェットがすでに存在します(ウィジェットID：%s)
 							$this->setAppErrorMsg($msg);
 						}
 					}
@@ -290,17 +290,13 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 								$extDir = $this->gEnv->getWidgetsPath() . '/' . M3_DIR_NAME_SMARTPHONE;
 								break;
 						}
-						/*if ($this->widgetType == '0'){		// PC用ウィジェット
-							$extDir = $this->gEnv->getWidgetsPath();
-						} else {		// 携帯用ウィジェット
-							$extDir = $this->gEnv->getWidgetsPath() . '/' . M3_DIR_NAME_MOBILE;
-						}*/
 					
 						// zipファイルを解凍
 						$zipFile = new PclZip($tmpFile);
 						if (($zipList = $zipFile->listContent()) == 0){
-							$msg = 'zipファイルの内容のリスト取得に失敗しました(要因: ' . $zipFile->errorName(true) . ')';
-							$this->setAppErrorMsg($msg);							
+							//$msg = 'zipファイルの内容のリスト取得に失敗しました(要因: ' . $zipFile->errorName(true) . ')';
+							$msg = sprintf($this->_('Failed in getting file list from zip file. (detail: %s)'), $zipFile->errorName(true));		// zipファイルの内容のリスト取得に失敗しました(要因: %s)
+							$this->setAppErrorMsg($msg);
 						} else {
 							// zipファイル名とディレクトリ名が同じであるかチェック
 							$dirName = $widgetName . '/';
@@ -310,7 +306,8 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 									// ディレクトリ削除
 									if ((is_dir($widgetPath) && rmDirectory($widgetPath)) || !is_dir($widgetPath)){// 削除成功か、ディレクトリが存在しないとき
 									} else {
-										$this->setMsg(self::MSG_APP_ERR, 'ウィジェットのディレクトリが削除できませんでした');
+										//$this->setMsg(self::MSG_APP_ERR, 'ウィジェットのディレクトリが削除できませんでした');
+										$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in deleting widget directory.'));	// ウィジェットのディレクトリが削除できませんでした
 									}
 								}
 								
@@ -372,42 +369,51 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 											
 											switch ($installType){
 												case 0:		// インストール
-													$msg = 'ウィジェットのインストールが完了しました。';
+													//$msg = 'ウィジェットのインストールが完了しました。';
+													$msg = $this->_('Widget installed successfully.');		// ウィジェットのインストールが完了しました。
 													break;
 												case 2:		// アップデート
-													$msg = 'ウィジェットの更新が完了しました。';
+													//$msg = 'ウィジェットの更新が完了しました。';
+													$msg = $this->_('Widget updated successfully.');		// ウィジェットの更新が完了しました。
 													break;
 											}
-											$msg .= 'バージョンは' . $version . 'です。';
+											//$msg .= 'バージョンは' . $version . 'です。';
+											$msg .= ' ' . sprintf($this->_('Current version is %s.'), $version);			// バージョンは$sです。
 											$this->setGuidanceMsg($msg);
 											
-											$msg = 'ファイルのアップロードが完了しました(ウィジェットID：' . $widgetId . ')';
+											//$msg = 'ファイルのアップロードが完了しました(ウィジェットID：' . $widgetId . ')';
+											$msg = sprintf($this->_('File uploaded. (widget ID: %s)'), $widgetId);		// ファイルのアップロードが完了しました(ウィジェットID: %s)
 											$this->setGuidanceMsg($msg);
 										} else {
-											$msg = 'ファイルのアップロードに失敗しました';
+											//$msg = 'ファイルのアップロードに失敗しました';
+											$msg = $this->_('Failed in uploading file.');		// ファイルのアップロードに失敗しました
 											$this->setAppErrorMsg($msg);
 										}
 
 										$this->newWidget[] = $widgetId;			// 新規ウィジェットID保存
 									} else {
-										$msg = 'ファイルのアップロードに失敗しました(要因: ' . $zipFile->errorName(true) . ')';
+										//$msg = 'ファイルのアップロードに失敗しました(要因: ' . $zipFile->errorName(true) . ')';
+										$msg = sprintf($this->_('Failed in uploading file. (detail: %s)'), $zipFile->errorName(true));	// ファイルのアップロードに失敗しました(要因: %s)
 										$this->setAppErrorMsg($msg);
 									}
 								}
 							} else {
-								$msg = 'zipファイルのファイル名とディレクトリ名が異なっているか、全角文字が含まれています';
+								//$msg = 'zipファイルのファイル名とディレクトリ名が異なっているか、全角文字が含まれています';
+								$msg = $this->_('The zip filename is different from directory name.');			// zipファイルのファイル名とディレクトリ名が異なっているか、全角文字が含まれています
 								$this->setAppErrorMsg($msg);
 							}
 						}
 					} else {
-						$msg = 'ファイルのアップロードに失敗しました';
+						//$msg = 'ファイルのアップロードに失敗しました';
+						$msg = $this->_('Failed in uploading file.');		// ファイルのアップロードに失敗しました
 						$this->setAppErrorMsg($msg);
 					}
 					// テンポラリファイル削除
 					unlink($tmpFile);
 				}
 			} else {
-				$msg = 'アップロードファイルが見つかりません(要因：アップロード可能なファイルのMaxサイズを超えている可能性があります - ' . $this->gSystem->getMaxFileSizeForUpload() . 'バイト)';
+				//$msg = 'アップロードファイルが見つかりません(要因：アップロード可能なファイルのMaxサイズを超えている可能性があります - ' . $this->gSystem->getMaxFileSizeForUpload() . 'バイト)';
+				$msg = sprintf($this->_('Uploded file not found. (detail: The file may be over maximum size to be allowed to upload. Size %d bytes.'), $this->gSystem->getMaxFileSizeForUpload());	// アップロードファイルが見つかりません(要因：アップロード可能なファイルのMaxサイズを超えている可能性があります。%dバイト)
 				$this->setAppErrorMsg($msg);
 			}
 		} else if ($act == 'download'){		// ファイルダウンロードのとき
@@ -431,16 +437,6 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 					$downloadFilename = $filename . '.zip';					// ダウンロード時のファイル名
 					break;
 			}
-			/*if ($this->widgetType == '0'){		// PC用ウィジェット
-				$widgetsDir = $this->gEnv->getWidgetsPath();		// ウィジェットディレクトリ
-				$widgetDir = $widgetsDir . '/' . $widgetId;		// ダウンロードするウィジェットのディレクトリ
-				$downloadFilename = $widgetId . '.zip';				// ダウンロード時のファイル名
-			} else {		// 携帯用ウィジェット
-				$widgetsDir = $this->gEnv->getWidgetsPath() . '/' . M3_DIR_NAME_MOBILE;		// ウィジェットディレクトリ
-				$widgetDir = $this->gEnv->getWidgetsPath() . '/' . $widgetId;				// ダウンロードするウィジェットのディレクトリ
-				list($dir, $filename) = explode('/', $widgetId);		// 先頭の「m/」を削除
-				$downloadFilename = $filename . '.zip';					// ダウンロード時のファイル名
-			}*/
 			$tmpFile = tempnam($this->gEnv->getWorkDirPath(), M3_SYSTEM_WORK_DOWNLOAD_FILENAME_HEAD);		// zip処理用一時ファイル
 			
 			// zip圧縮
@@ -457,7 +453,8 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 				$this->gPage->exitSystem();
 				//return;
 			} else {
-				$msg = 'ファイルのダウンロードに失敗しました(要因: ' . $zipFile->errorName(true) . ')';
+				//$msg = 'ファイルのダウンロードに失敗しました(要因: ' . $zipFile->errorName(true) . ')';
+				$msg = sprintf($this->_('Failed in downloading file. (detail: %s)'), $zipFile->errorName(true));		// ファイルのダウンロードに失敗しました(要因: %s)
 				$this->setAppErrorMsg($msg);
 				
 				// テンポラリファイル削除
@@ -483,11 +480,6 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 				$installDir = $this->gEnv->getWidgetsPath() . '/' . M3_DIR_NAME_SMARTPHONE;// ウィジェット格納ディレクトリ
 				break;
 		}
-		/*if ($this->widgetType == '0'){		// PC用ウィジェット
-			$installDir = $this->gEnv->getWidgetsPath();// ウィジェット格納ディレクトリ
-		} else {			// 携帯用ウィジェット
-			$installDir = $this->gEnv->getWidgetsPath() . '/' . M3_DIR_NAME_MOBILE;// ウィジェット格納ディレクトリ
-		}*/
 
 		// 表示制御
 		if (!empty($this->showDetail)){		// 詳細表示のとき
@@ -507,9 +499,30 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 		$this->tmpl->addVar("_widget", "show_detail", $checkedStr);		// 詳細表示
 		$this->tmpl->addVar("show_dir", "install_dir", $installDir);// インストールディレクトリを設定
 		
+		// テキストをローカライズ
+		$localeText = array();
+		$localeText['msg_update_line'] = $this->_('Update line?');		// 行を更新しますか?
+		$localeText['msg_delete_line'] = $this->_('Delete widget?');		// このウィジェットを削除しますか?
+		$localeText['msg_no_upload_file'] = $this->_('File not selected.');		// アップロードするファイルが選択されていません
+		$localeText['msg_upload_file'] = $this->_('Upload file.');		// ファイルをアップロードします
+		$localeText['label_widget_list'] = $this->_('Widget List');			// ウィジェット一覧
+		$localeText['label_widget_type'] = $this->_('Widget Type:');			// ウィジェットタイプ：
+		$localeText['label_install_dir'] = $this->_('Install Directory:');			// インストールディレクトリ:
+		$localeText['label_read_new'] = $this->_('Reload directory');			// ディレクトリ再読み込み
+		$localeText['label_show_detail'] = $this->_('Show detail');			// 詳細表示
+		$localeText['label_widget_name'] = $this->_('Name');			// 名前
+		$localeText['label_widget_version'] = $this->_('Version');			// バージョン
+		$localeText['label_widget_available'] = $this->_('Available');			// 配置可
+		$localeText['label_widget_active'] = $this->_('Active');			// 実行可
+		$localeText['label_widget_date'] = $this->_('Update Date');			// 更新日時
+		$localeText['label_widget_operation'] = $this->_('Operation');			// 操作
+		$localeText['label_widget_upload'] = $this->_('Widget Upload (zip compressed file)');			// ウィジェットアップロード(zip圧縮ファイル)
+		$localeText['msg_replace_widget'] = $this->_('Replace widget if exists.');			// ウィジェットが存在する場合は置き換え
+		$localeText['label_upload'] = $this->_('Upload');			// アップロード
+		$this->setLocaleText($localeText);
 		// ヘルプの追加
-		$this->convertHelp('show_list_detail');
-		$this->convertHelp('show_dir');
+		//$this->convertHelp('show_list_detail');
+		//$this->convertHelp('show_dir');
 	}
 	/**
 	 * ウィジェットのディレクトリの状態を取得
@@ -667,7 +680,8 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 			$iconTitle = '';
 			$iconUrl = $this->gDesign->getWidgetIconUrl($widgetId, $this->defaultImageSize);
 		} else {
-			$iconTitle = self::NOT_FOUND_WIDGET_MESSAGE;		// ウィジェットが見つかりません
+			//$iconTitle = self::NOT_FOUND_WIDGET_MESSAGE;		// ウィジェットが見つかりません
+			$iconTitle = $this->_('Widget not found.');		// ウィジェットが見つかりません
 			$iconUrl = $this->gEnv->getRootUrl() . self::NOT_FOUND_WIDGET_ICON_FILE;
 		}
 		$imageTag = '<img class="widget_obj" src="' . $this->getUrl($iconUrl) . '" ';
@@ -703,7 +717,11 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 			'delete_button' => $buttonEnabled,									// 削除ボタンの使用制御
 			'detail_button' => $detailButtonEnabled,							// 詳細ボタンの使用制御
 			'download_button' => $downloadButton,								// ダウンロードボタン
-			'image_tag' => $imageTag		// 画像
+			'image_tag' => $imageTag,		// 画像
+			'label_widget_config' => $this->_('Configure'),			// 設定
+			'label_update' => $this->_('Update'),			// 更新
+			'label_delete' => $this->_('Delete'),			// 削除
+			'label_download' => $this->_('Download')			// ダウンロード
 		);
 		$this->tmpl->addVars('widgetlist', $row);
 		$this->tmpl->parseTemplate('widgetlist', 'a');
