@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 3862 2010-11-24 08:25:29Z fishbone $
+ * @version    SVN: $Id: index.php 3871 2010-12-01 10:08:24Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -87,30 +87,6 @@ $HELP['userlist_del_btn']['body'] = '選択されているユーザを削除し
 $HELP['userlist_ret_btn']['title'] = '戻るボタン';
 $HELP['userlist_ret_btn']['body'] = 'ユーザ一覧へ戻ります。';
 
-// ########## ウィジェット一覧 ##########
-$HELP['widgetlist']['title'] = 'ウィジェット一覧';
-$HELP['widgetlist']['body'] = 'システムで利用可能なウィジェットの一覧です。ウィジェットのインストールはこの画面の最下部の「ウィジェットアップロード」から行います。';
-$HELP['widgetlist_type']['title'] = 'ウィジェットタイプ';
-$HELP['widgetlist_type']['body'] = 'PC用のウィジェットか携帯用のウィジェットかを選択します。';
-$HELP['widgetlist_install_dir']['title'] = 'ウィジェットインストールディレクトリ';
-$HELP['widgetlist_install_dir']['body'] = 'ウィジェットのインストールディレクトリです。この配下に「ウィジェットID」のディレクトリ名で個々のウィジェットが格納されます。';
-$HELP['widgetlist_id']['title'] = 'ID';
-$HELP['widgetlist_id']['body'] = 'ウィジェットのIDです。ウィジェットのディレクトリ名と同一です。';
-$HELP['widgetlist_name']['title'] = '名前';
-$HELP['widgetlist_name']['body'] = 'ウィジェットの名前です。';
-$HELP['widgetlist_available']['title'] = '配置可能';
-$HELP['widgetlist_available']['body'] = 'ウィジェットを配置用の選択メニューに表示するかどうかを指定します。すでにページに配置されているウィジェットはそのまま維持されます。';
-$HELP['widgetlist_active']['title'] = '実行可能';
-$HELP['widgetlist_active']['body'] = 'ウィジェットの実行を許可します。特定のウィジェットを緊急停止する場合に使用します。';
-$HELP['widgetlist_act']['title'] = '操作';
-$HELP['widgetlist_act']['body'] = '各種操作を行います。<br />●更新<br />この一覧で変更した値を保存します。<br />●削除<br />ウィジェットをシステムから削除します。<br />●設定<br />ウィジェットの設定画面を表示します。ウィジェットの設定画面はページ作成画面やトップメニュー画面からも表示可能です。<br />●ダウンロード<br />ウィジェットをZIP圧縮形式でダウンロードします。このファイルはそのまま「ウィジェットアップロード」からシステムへインストールできる形式です。';
-$HELP['widgetlist_upload']['title'] = 'ウィジェットアップロード';
-$HELP['widgetlist_upload']['body'] = 'ZIP形式のウィジェットファイルをアップロードし、システムにウィジェットをインストールします。同じIDのウィジェットがすでに存在する場合はエラーになります。<br />「ウィジェットが存在する場合は置き換え」にチェックが入っている場合、既存のウィジェットを削除した後、ウィジェットをインストールします。';
-$HELP['widgetlist_detail_check']['title'] = '詳細表示';
-$HELP['widgetlist_detail_check']['body'] = 'チェックを入れると一覧が詳細表示できます。';
-$HELP['widgetlist_reload_dir_btn']['title'] = 'ディレクトリ再読み込み';
-$HELP['widgetlist_reload_dir_btn']['body'] = 'ウィジェットディレクトリを再読み込みして、一覧に表示されていないウィジェットを自動的にインストールします。';
-
 // ########## テンプレート一覧 ##########
 $HELP['templist']['title'] = 'テンプレート一覧';
 $HELP['templist']['body'] = 'システムで利用可能なテンプレートの一覧です。テンプレートのインストールはこの画面の最下部の「テンプレートアップロード」から行います。';
@@ -135,44 +111,6 @@ $HELP['templist_detail_check']['body'] = 'チェックを入れると一覧が
 $HELP['templist_reload_dir_btn']['title'] = 'ディレクトリ再読み込み';
 $HELP['templist_reload_dir_btn']['body'] = 'テンプレートディレクトリを再読み込みして、一覧に表示されていないテンプレートを自動的にインストールします。';
 
-// ########## 画面作成 ##########
-$HELP['pagedef_page_id']['title'] = 'ページID';
-$HELP['pagedef_page_id']['body'] = 'ページを定義するためのIDです。IDはURLに付加されます。非公開項目は管理権限のない一般ユーザには公開されないページです。';
-$HELP['pagedef_page_sub_id']['title'] = 'ページサブID';
-$HELP['pagedef_page_sub_id']['body'] = 'ページを定義するための補助IDです。IDはURLに付加されます。';
-$HELP['pagedef_preview_url']['title'] = 'URL';
-$HELP['pagedef_preview_url']['body'] = 'プレビューに表示しているページへのURLです。';
-$HELP['pagedef_detail_btn']['title'] = '詳細ボタン';
-$HELP['pagedef_detail_btn']['body'] = 'ページ定義の詳細を表示します。';
-$HELP['pagedef_maximize_btn']['title'] = '最大化ボタン';
-$HELP['pagedef_maximize_btn']['body'] = 'レイアウト画面を最大化します。画面を元に戻すにはESCキーを押します。ESCキーでも最大化できます。';
-$HELP['pagedef_default_template']['title'] = 'デフォルトテンプレート';
-$HELP['pagedef_default_template']['body'] = 'デフォルトで設定されるデザインテンプレートを指定します。';
-$HELP['pagedef_change_template_btn']['title'] = 'テンプレート変更';
-$HELP['pagedef_change_template_btn']['body'] = 'デフォルトのテンプレートを変更します。';
-$HELP['pagedef_template_img']['title'] = 'テンプレート表示イメージ';
-$HELP['pagedef_template_img']['body'] = 'テンプレートを設定した場合の画面の表示イメージです。';
-$HELP['pagedef_widget']['title'] = 'ウィジェット';
-$HELP['pagedef_widget']['body'] = 'レイアウトに配置可能なウィジェットです。シングルクリックで取得し、画面レイアウト領域に配置します。';
-$HELP['pagedef_layout']['title'] = '画面レイアウト';
-$HELP['pagedef_layout']['body'] = '(ウィジェットの配置)<br />テンプレートにウィジェットを配置し、画面を作成します。ウィジェット一覧からマウスドラッグでウィジェットを取り出します。レイアウト画面の任意のポジション位置にドロップするとウィジェットが配置できます。レイアウト画面からウィジェットを削除するには、削除するウィジェットの右上のクローズボックスをクリックします。一度ドロップしたウィジェットは、ドラッグドロップでページ上の移動が可能です。最大化ボタンまたはESCキーでレイアウト画面が最大化できます。最大化状態から元に戻るにはESCキーを押します。<br />(ウィジェットコンテキストメニュー)<br />ウィジェットをマウス右クリックするとコンテキストメニューが表示されます。ウィジェットの設定を行ったり、ウィジェットの削除を行います。「ページ共通」属性を設定したウィジェットは、ページに関わらず常に表示されます。(赤色表示)';
-$HELP['pagedef_preview']['title'] = 'レイアウトとプレビューの切り替えボタン';
-$HELP['pagedef_preview']['body'] = 'ウィジェットの配置を行うレイアウト画面と、実際に表示されるプレビュー画面を切り替えます。';
-$HELP['pagedef_refresh']['title'] = '画面再表示';
-$HELP['pagedef_refresh']['body'] = 'レイアウトまたはプレビュー画面を再表示します。';
-$HELP['pagedef_preview_other']['title'] = '別画面でプレビュー';
-$HELP['pagedef_preview_other']['body'] = '実際に表示される画面を別ウィンドウで表示します。';
-$HELP['pagedef_position_block']['title'] = 'ポジション名';
-$HELP['pagedef_position_block']['body'] = 'デザインテンプレート内でのウィジェットの配置ブロックを指定します。';
-$HELP['pagedef_position_index']['title'] = '表示順';
-$HELP['pagedef_position_index']['body'] = 'ポジションブロック内でのウィジェットの表示順を指定します。';
-$HELP['pagedef_widget_def_id']['title'] = '定義ID';
-$HELP['pagedef_widget_def_id']['body'] = '個別のウィジェットの設定IDです。設定が必要な場合のみ設定可能になります。';
-$HELP['pagedef_widget_visible']['title'] = 'ウィジェット表示制御';
-$HELP['pagedef_widget_visible']['body'] = 'ウィジェットの表示、非表示を制御します。';
-$HELP['pagedef_widget_common']['title'] = 'ページ共通属性';
-$HELP['pagedef_widget_common']['body'] = '同ページIDで、サブページIDに関わらずウィジェットを表示するかどうかを指定します。';
-
 // ########## テーブルデータ編集 ##########
 $HELP['edittable_new_btn']['title'] = '新規ボタン';
 $HELP['edittable_new_btn']['body'] = '新規レコードを追加します。';
