@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 3757 2010-10-29 10:34:41Z fishbone $
+ * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 3762 2010-10-31 05:41:08Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_default_contentBaseWidgetContainer.php');
@@ -32,6 +32,8 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 	const CALENDAR_ICON_FILE = '/images/system/calendar.png';		// カレンダーアイコン
 	const ACTIVE_ICON_FILE = '/images/system/active.png';			// 公開中アイコン
 	const INACTIVE_ICON_FILE = '/images/system/inactive.png';		// 非公開アイコン
+	const ADD_TO_MENU_ICON_FILE = '/images/system/addtomenu.png';		// メニューに追加用アイコン
+	const PREVIEW_ICON_FILE = '/images/system/preview.png';		// プレビュー用アイコン
 	const MSG_UPDATE_CONTENT = 'コンテンツを更新しました';			// コンテンツ更新メッセージ
 	const DEFAULT_SEARCH_KEY = '1';			// デフォルトの検索キー(更新日時)
 	const DEFAULT_SEARCH_ORDER = '1';			// デフォルトの検索ソート順(降順)
@@ -515,6 +517,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 	function itemListLoop($index, $fetchedRow, $param)
 	{
 		$serial = $this->convertToDispString($fetchedRow['cn_serial']);
+		$contentId = $fetchedRow['cn_id'];		// コンテンツID
 		
 		// 表示状態
 		$visible = '';
@@ -530,7 +533,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		
 		// 対応言語を取得
 		$lang = '';
-		$ret = $this->db->getLangByContentId($fetchedRow['cn_id'], $rows);
+		$ret = $this->db->getLangByContentId($contentId, $rows);
 		if ($ret){
 			$count = count($rows);
 			for ($i = 0; $i < $count; $i++){
@@ -562,10 +565,17 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 			$iconTitle = '非公開';
 		}
 		$statusImg = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
+		
+		// 操作用ボタン
+		$addToMenuImg = $this->getUrl($this->gEnv->getRootUrl() . self::ADD_TO_MENU_ICON_FILE);		// メニューに追加用アイコン
+		$addToMenuStr = 'メニューに追加';
+		$previewUrl = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_CONTENT_ID . '=' . $contentId . '&' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_PREVIEW;// プレビュー用URL
+		$previewImg = $this->getUrl($this->gEnv->getRootUrl() . self::PREVIEW_ICON_FILE);
+		$previewStr = 'プレビュー';
 		$row = array(
 			'index' => $index,													// 項目番号
 			'serial' => $serial,			// シリアル番号
-			'id' => $this->convertToDispString($fetchedRow['cn_id']),			// ID
+			'id' => $this->convertToDispString($contentId),			// ID
 			'name' => $this->convertToDispString($fetchedRow['cn_name']),		// 名前
 			'lang' => $lang,													// 対応言語
 			'view_count' => $totalViewCount,									// 総参照数
@@ -574,7 +584,12 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 			'update_dt' => $this->convertToDispDateTime($fetchedRow['cn_create_dt']),	// 更新日時
 			'visible' => $visible,											// メニュー項目表示制御
 			'limited' => $limited,											// ユーザ制限
-			'default' => $default											// デフォルト項目
+			'default' => $default,											// デフォルト項目
+			'add_to_menu_img' => $addToMenuImg,											// メニューに追加用の画像
+			'add_to_menu_str' => $addToMenuStr,											// メニューに追加用の文字列
+			'preview_url' => $previewUrl,											// プレビュー用のURL
+			'preview_img' => $previewImg,											// プレビュー用の画像
+			'preview_str' => $previewStr									// プレビュー文字列
 		);
 		$this->tmpl->addVars('itemlist', $row);
 		$this->tmpl->parseTemplate('itemlist', 'a');
