@@ -8,14 +8,14 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_reserve_mainBaseWidgetContainer.php 487 2008-04-09 06:53:26Z fishbone $
+ * @version    SVN: $Id: admin_reserve_mainBaseWidgetContainer.php 2458 2009-10-24 07:26:44Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
 
-class admin_reserve_mainBaseWidgetContainer extends BaseWidgetContainer
+class admin_reserve_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 {
 	/**
 	 * コンストラクタ
