@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: static_contentWidgetContainer.php 3157 2010-05-26 02:26:56Z fishbone $
+ * @version    SVN: $Id: static_contentWidgetContainer.php 3531 2010-08-26 05:34:41Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -74,7 +74,8 @@ class static_contentWidgetContainer extends BaseWidgetContainer
 		if (!empty($targetObj)){		// 定義データが取得できたとき
 			$name = $targetObj->name;// 定義名
 			$contentId	= $targetObj->contentId;		// コンテンツID
-
+			$hideInLogin = $targetObj->hideInLogin;		// ログイン中は非表示にする
+			
 			// コンテンツを取得
 			$ret = $this->db->getContentByContentId(self::CONTENT_TYPE, $contentId, $this->langId, $now, $row);
 			if ($ret){
@@ -86,6 +87,9 @@ class static_contentWidgetContainer extends BaseWidgetContainer
 			
 				// ログインユーザに表示が制限されている場合は非表示
 				if ($this->gEnv->isCurrentUserLogined() || !$row['cn_user_limited']) $showWidget = true;
+				
+				// ログイン中は非表示に設定されているときは非表示にする
+				if (!empty($hideInLogin) && $this->gEnv->isCurrentUserLogined()) $showWidget = false;
 			}
 		}
 		// ウィジェットの表示
